@@ -8,7 +8,7 @@ use XSLoader;
 use Scalar::Util qw/ blessed /;
 
 BEGIN {
-    our $VERSION = '1.002';
+    our $VERSION = '1.003';
     XSLoader::load();
 }
 
@@ -100,9 +100,7 @@ sub _exception_match_args {
 }
 
 sub _rethrow {
-    my ($exception) = @_;
-    local $SIG{__DIE__} = undef;
-    die $exception;
+    die (@_);
 }
 
 sub _get_return_value {
